@@ -83,7 +83,9 @@ def pack_log(input_args):
 
     # get current datetime like 20210913175500
     cur_datetime = datetime.now().strftime("%Y%m%d%H%M%S")
-    output_file_name = f"{cur_datetime}.log.tar.gz"
+    # get system hostname
+    hostname = os.popen("hostname").read().strip()
+    output_file_name = f"{hostname}-{cur_datetime}.log.tar.gz"
     # join args.output_directory and OUTPUT_FILE_NAME
     output_file_path = os.path.join(input_args.output_directory, output_file_name)
 
@@ -113,6 +115,8 @@ def pack_log(input_args):
     # terminal process bar for compress with alive-progress
     print(f"pack complete, total {len(log_files)} files, output file: {output_file_path}")
 
+    upload_to_obs(output_file_path)
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(
         description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter
